## feinsum

<div align="center">
<img src="https://raw.githubusercontent.com/kaushikcfd/feinsum/main/doc/static/logo.svg" alt="logo"></img>
</div>

![Continuous integration](https://github.com/kaushikcfd/feinsum/actions/workflows/ci.yml/badge.svg)
![PyPI version](https://img.shields.io/pypi/v/feinsum)


### What is feinsum?

*Feinsum*, short for Fast-Einstein Summations, provides tools for managing
databases of code-transformations on *Batched Einstein Summations*. Unlike
typical computational primitive libraries that ship optimized computational
kernel in source or binary form, *feinsum* records code-transformations from
a trivial schedule, resulting in relative savings from not having to flush the
operands to the DRAM.


### Links
- Install as [`pip install feinsum`](https://pypi.org/project/loopy).
- Read the documentation at <https://feinsum.readthedocs.io>.
- Source-code, Issue Management at <https://github.com/kaushikcfd/feinsum>.
